@@ -5,6 +5,7 @@ Pyro - Python Remote Objects.  Copyright by Irmen de Jong (irmen@razorvine.net).
 """
 
 import sys
+from Pyro4.constants import VERSION as __version__
 
 if sys.version_info < (2, 7):
     import warnings
@@ -56,14 +57,8 @@ def _configLogging():
 _configLogging()
 del _configLogging
 
-# initialize Pyro's configuration
-from Pyro4.configuration import Configuration
-
-config = Configuration()
-del Configuration
-
 # import the required Pyro symbols into this package
+from Pyro4.configuration import config
 from Pyro4.core import URI, Proxy, Daemon, callback, batch, async, oneway, expose, behavior, current_context
-from Pyro4.naming import locateNS, resolve
+from Pyro4.core import _locateNS as locateNS, _resolve as resolve
 from Pyro4.futures import Future
-from Pyro4.constants import VERSION as __version__
